"""-------------------------------------------------------------------
Cours : TNSI - BDD SQLite - Python - Serveur WEB
Titre : LISTE DES CHOSES A FAIRE (final)
Langages : Python, HTML, SQL
Source : https://funprojects.blog/2020/03/30/sqlite-bottle-todo-list/
plus loin : https://bottlepy.org/docs/dev/tutorial_app.html
Module : sqlite3, bottle
Objectifs : insérer les données extraites d'une base SQLite dans un 
gabarit HTML et l'afficher dans un navigateur. Les ajouts et les 
suppressions d'éléments sont possibles dans la base. Feuille de
style CSS.
Codage : fonction, boucle, test
Ressource : https://bottlepy.org/docs/dev/, 
https://www.sqlite.org/index.html
Date : 18/4/2021
Fichiers : matodolist.py, pagev3.tpl, todo.db, creation.sql
Schéma de la table todo : (categorie:char(50), sujet:char(100), id:INT)
--------------------------------------------------------------------"""
import sqlite3
import bottle

# Chargement du fichier style.css


@bottle.route('/css/<filename:path>')
def server_static(filename):
    " Fichiers statiques du site placés dans le rép /css/ "
    return bottle.static_file(filename, root='css')


@bottle.route('/')  # Définition d'une route et d'un
def accueil():      # gestionnaire pour la page d'accueil
    # 1. Connexion à la base de données
    connexion = sqlite3.connect('bdd/todo.db')
    # 2. Création d'un curseur pour exécuter les requêtes
    curseur = connexion.cursor()
    # 3. Exécution de la requête
    curseur.execute("SELECT * FROM todo ORDER BY categorie,sujet")
    # Rem : Le résultat renvoyé par la requête est une liste de tuples
    resultat = curseur.fetchall()
    # 4. Deconnexion
    curseur.close()
    # 5. Identification de la page à utiliser
    html = bottle.template('pagesweb/pagev3.tpl', table=resultat)
    # 6. Transmission des données au navigateur
    return html


@bottle.route('/ajout', method='POST')
def ajouter():  # Ajout de nouveaux éléments dans la table todo
    # a. Acquisition des données transmises par le formulaire
    nouveauSujet = bottle.request.forms.get("sujet")
    nouvelleCategorie = bottle.request.forms.get("nouvelleCategorie")

    if nouveauSujet != "":
        # b1. Connexion à la base de données
        connexion = sqlite3.connect('bdd/todo.db')
        # b2. Création d'un curseur pour exécuter les requêtes
        curseur = connexion.cursor()
        # b3. Exécution de la requête
        curseur.execute(
            "INSERT INTO todo (categorie,sujet) VALUES (?,?)", (nouvelleCategorie, nouveauSujet))
        # b4. Mise à jour de la table
        connexion.commit()
        # b5. Deconnexion
        curseur.close()
        # b6. Retour à la page principale pour afficher la liste modifiée
        bottle.redirect("/")


@bottle.route('/retrait', method='POST')
def retirer():  # Retrait d'un élément dans la table todo
    # a. Identification de l'élément à retirer
    idelem = bottle.request.forms.get("supprimeItem").strip()
    # b1. Connexion à la base de données
    connexion = sqlite3.connect('bdd/todo.db')
    # b2. Création d'un curseur pour exécuter les requêtes
    curseur = connexion.cursor()
    # b3. Exécution de la requête
    sqlstr = f"DELETE FROM todo WHERE id={str(idelem)}"
    curseur.execute(sqlstr)
    # b4. Mise à jour de la table
    connexion.commit()
    # b5. Deconnexion
    curseur.close()
    # b6. Retour à la page principale pour afficher la liste modifiée
    bottle.redirect("/")


if __name__ == '__main__':
    # run() démarre le micro serveur Web Bottle sur: http://127.0.0.1:port/
    bottle.run(bottle.app(), host='127.0.0.1',
               port=8080, debug=True, reloader=True)
